import { App } from 'vue';
import { SearchOptions as SearchOptions$1 } from 'minisearch';

type Word = [tag: string, content: string] | string;
interface TitleMatchedItem {
    type: "title";
    id: string;
    display: Word[];
}
interface HeadingMatchedItem {
    type: "heading";
    id: string;
    display: Word[];
}
interface CustomMatchedItem {
    type: "custom";
    id: string;
    index: string;
    display: Word[];
}
interface ContentMatchedItem {
    type: "content";
    id: string;
    header: string;
    display: Word[];
}
type MatchedItem = TitleMatchedItem | HeadingMatchedItem | ContentMatchedItem | CustomMatchedItem;
interface SearchResult {
    title: string;
    contents: MatchedItem[];
}

type SearchOptions = Omit<SearchOptions$1, "fields">;

declare const defineSearchConfig: (options: SearchOptions) => void;
declare const useSearchOptions: () => SearchOptions;
declare const injectMiniSearchConfig: (app: App) => void;

interface SearchWorker {
    search: (query: string, locale: string, searchOptions?: SearchOptions) => Promise<SearchResult[]>;
    terminate: () => void;
}
declare const createSearchWorker: () => SearchWorker;

export { SearchWorker, createSearchWorker, defineSearchConfig, injectMiniSearchConfig, useSearchOptions };
